@@ -33,6 +33,6 @@ then
     controldoc
 else
     dodoc $1
-    mv $1.1 ../man/$1.1
+    mv *.1 ../man
     mv $1.html ../doc/html/$1.html
 fi
